@@ -1,15 +1,20 @@
-# Copyright (C) 2015 Anne Mulhern
+# Copyright (C) 2015 - 2019 Red Hat, Inc.
 #
-# This copyrighted material is made available to anyone wishing to use,
-# modify, copy, or redistribute it subject to the terms and conditions of
-# the GNU General Public License v.2, or (at your option) any later version.
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY expressed or implied, including the implied warranties of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-# Public License for more details.  You should have received a copy of the
-# GNU General Public License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# Anne Mulhern <mulhern@cs.wisc.edu>
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; If not, see <http://www.gnu.org/licenses/>.
+#
+# Red Hat Author(s): Anne Mulhern <amulhern@redhat.com>
+# Other author(s): Anne Mulhern <mulhern@cs.wisc.edu>
 
 """
 Methods dealing with rationals.
@@ -29,7 +34,7 @@ from ._errors import BasesValueError
 from ._nats import Nats
 
 
-class Radices(object):
+class Radices():
     """
     Methods for Radices.
     """
@@ -76,6 +81,7 @@ class Radices(object):
 
         Complexity: Uncalculated.
         """
+        # pylint: disable=too-many-locals
         if to_base < 2:
             raise BasesValueError(to_base, "to_base", "must be at least 2")
 
@@ -126,7 +132,7 @@ class Radices(object):
         return (result, relation)
 
 
-class Rationals(object):
+class Rationals():
     """
     Miscellaneous methods for rationals.
     """
@@ -175,13 +181,12 @@ class Rationals(object):
         if method is RoundingMethods.ROUND_HALF_ZERO:
             if lower < 0:
                 return (upper, 1) if delta >= Fraction(1, 2) else (lower, -1)
-            else:
-                return (lower, -1) if delta <= Fraction(1, 2) else (upper, 1)
+            return (lower, -1) if delta <= Fraction(1, 2) else (upper, 1)
 
         raise BasesValueError(method, "method")
 
 
-class Radix(object):
+class Radix():
     """
     An object containing information about a rational representation.
 
@@ -365,7 +370,7 @@ class Radix(object):
                base
             )
             if error is not None:
-                raise error
+                raise error # pylint: disable=raising-bad-type
 
         if canonicalize:
             if all(x == 0 for x in integer_part):
@@ -531,7 +536,7 @@ class Radix(object):
         return result
 
 
-class _Rounding(object):
+class _Rounding():
     """
     Rounding of radix objects.
     """
@@ -641,7 +646,7 @@ class _Rounding(object):
         )
 
         if all(x == 0 for x in value.non_repeating_part[precision:]) and \
-           len(value.repeating_part) == 0:
+           value.repeating_part == []:
             return (truncated(), 0)
 
         if method is RoundingMethods.ROUND_TO_ZERO:
@@ -671,12 +676,9 @@ class _Rounding(object):
         middle = Fraction(1, 2)
         if remainder_fraction < middle:
             return (truncated(), -1 * value.sign)
-        elif remainder_fraction > middle:
+        if remainder_fraction > middle:
             return (incremented(), value.sign)
-        else:
-            if cls._conditional_toward_zero(method, value.sign):
-                return (truncated(), -1 * value.sign)
-            else:
-                return (incremented(), value.sign)
 
-        raise BasesAssertError() # pragma: no cover
+        if cls._conditional_toward_zero(method, value.sign):
+            return (truncated(), -1 * value.sign)
+        return (incremented(), value.sign)
